@@ -1,7 +1,7 @@
 # vim:fileencoding=utf-8
 # Copyright (c) 2007 gocept gmbh & co. kg
 # See also LICENSE.txt
-# $Id: content.py 5505 2007-12-21 13:06:05Z ctheune $
+# $Id: content.py 5658 2008-04-08 12:46:08Z mac $
 """Interaction between the reference machinery and content objects."""
 
 import transaction
@@ -19,7 +19,7 @@ import gocept.reference.reference
 def find_references(obj):
     for name in dir(obj):
         attr = getattr(obj.__class__, name, None)
-        if isinstance(attr, gocept.reference.reference.Reference):
+        if isinstance(attr, gocept.reference.reference.ReferenceBase):
             yield name, attr
 
 
@@ -38,7 +38,7 @@ class ReferenceSource(object):
             if target_key:
                 try:
                     ref.lookup(target_key)
-                except gocept.reference.interfaces.IntegrityError:
+                except gocept.reference.interfaces.LookupError:
                     return False
         return True
 
@@ -104,18 +104,14 @@ def ensure_referential_integrity(obj, event):
         gocept.reference.interfaces.IReferenceManager)
     if manager.is_referenced(old_path):
         transaction.doom()
-        raise gocept.reference.interfaces.IntegrityError(
-            "Can't delete or move %r. "
-            "The (sub-)object %r is still being referenced." % 
-            (event.object, obj))
+        raise gocept.reference.interfaces.IntegrityError(event.object, obj)
 
 
 @zope.component.adapter(zope.interface.Interface,
                         zope.app.container.interfaces.IObjectAddedEvent)
 def ensure_registration(obj, event):
     for name, ref in find_references(obj):
-        if ref.storage(obj).get(name):
-            ref._register(obj)
+        ref._register(obj)
 
 
 @zope.component.adapter(zope.interface.Interface,
